@@ -1,9 +1,7 @@
 pub use backend_arg::BackendArg;
-pub use env_arg::{ENV_ARG, PROFILE_ARG};
 pub use env_var_arg::EnvVarArg;
 pub use tool_arg::{ToolArg, ToolVersionType};
 
 mod backend_arg;
-mod env_arg;
 mod env_var_arg;
 mod tool_arg;
