@@ -163,6 +163,10 @@ pub struct Run {
     #[clap(long, alias = "no-timing", verbatim_doc_comment)]
     pub no_timings: bool,
 
+    /// Run only the specified tasks skipping all dependencies
+    #[clap(long, verbatim_doc_comment, env = "MISE_TASK_SKIP_DEPENDS")]
+    pub skip_deps: bool,
+
     /// Timeout for the task to complete
     /// e.g.: 30s, 5m
     #[clap(long, verbatim_doc_comment)]
@@ -198,6 +202,42 @@ impl Run {
             self.get_clap_command().print_long_help()?;
             return Ok(());
         }
+
+        if !self.skip_deps {
+            self.skip_deps = Settings::get().task_skip_depends;
+        }
+
+        // Check if --help or -h is in the args (before executing the task)
+        // This handles cases like: mise run --cd dir task --help
+        // NOTE: Only check self.args, not self.args_last, because args_last contains
+        // arguments after -- which should always be passed through to the task
+        let has_help_flag =
+            self.args.contains(&"--help".to_string()) || self.args.contains(&"-h".to_string());
+
+        if has_help_flag {
+            // Remove --help/-h from args to get the task
+            self.args.retain(|arg| arg != "--help" && arg != "-h");
+            self.args_last.retain(|arg| arg != "--help" && arg != "-h");
+
+            // Build args list to get the task
+            let args = once(self.task.clone())
+                .chain(self.args.clone())
+                .collect_vec();
+
+            let task_list = get_task_lists(&config, &args, false, false).await?;
+
+            if let Some(task) = task_list.first() {
+                // Get usage spec and display help using usage library
+                let spec = task.parse_usage_spec_for_display(&config).await?;
+                // Render help using usage library
+                println!("{}", usage::docs::cli::render_help(&spec, &spec.cmd, true));
+            } else {
+                // No task found, show run command help
+                self.get_clap_command().print_long_help()?;
+            }
+            return Ok(());
+        }
+
         time!("run init");
         let tmpdir = tempfile::tempdir()?;
         self.tmpdir = tmpdir.path().to_path_buf();
@@ -207,7 +247,7 @@ impl Run {
             .chain(self.args.clone())
             .collect_vec();
 
-        let mut task_list = get_task_lists(&config, &args, true).await?;
+        let mut task_list = get_task_lists(&config, &args, true, self.skip_deps).await?;
 
         // Args after -- go directly to tasks (no prefix)
         if !self.args_last.is_empty() {
@@ -459,6 +499,7 @@ impl Run {
             timings: self.timings,
             continue_on_error: self.continue_on_error,
             dry_run: self.dry_run,
+            skip_deps: self.skip_deps,
         };
         self.executor = Some(crate::task::task_executor::TaskExecutor::new(
             self.context_builder.clone(),
