@@ -1,41 +1,19 @@
-use regex::Regex;
 use std::collections::HashSet;
 use std::sync::LazyLock;
 use std::sync::Mutex;
 
-pub static UNNEST_RE: LazyLock<Regex> =
-    LazyLock::new(|| Regex::new(r#"MISE_TASK_UNNEST:(\d+):MISE_TASK_UNNEST (.*)"#).unwrap());
-
 #[macro_export]
 macro_rules! prefix_println {
     ($prefix:expr, $($arg:tt)*) => {{
         let msg = format!($($arg)*);
-        if let Some(msg) = $crate::output::UNNEST_RE.captures(&msg) {
-            let level = msg.get(1).unwrap().as_str().parse::<usize>().unwrap();
-            if level > 1 {
-                println!("MISE_TASK_UNNEST:{}:MISE_TASK_UNNEST {}", level - 1, msg.get(2).unwrap().as_str());
-            } else {
-                println!("{}", msg.get(2).unwrap().as_str());
-            }
-        } else {
-            println!("{} {}", $prefix, msg);
-        }
+        println!("{} {}", $prefix, msg);
     }};
 }
 #[macro_export]
 macro_rules! prefix_eprintln {
     ($prefix:expr, $($arg:tt)*) => {{
         let msg = format!($($arg)*);
-        if let Some(msg) = $crate::output::UNNEST_RE.captures(&msg) {
-            let level = msg.get(1).unwrap().as_str().parse::<usize>().unwrap();
-            if level > 1 {
-                eprintln!("MISE_TASK_UNNEST:{}:MISE_TASK_UNNEST {}", level - 1, msg.get(2).unwrap().as_str());
-            } else {
-                eprintln!("{}", msg.get(2).unwrap().as_str());
-            }
-        } else {
-            eprintln!("{} {}", $prefix, msg);
-        }
+        eprintln!("{} {}", $prefix, msg);
     }};
 }
 
