@@ -104,28 +104,28 @@ impl ZigPlugin {
             None
         };
 
-        if settings.zig.use_community_mirrors {
-            if let Some(mirrors) = community_mirrors {
-                for i in 0..mirrors.len() {
-                    let disp_i = i + 1;
-                    let disp_len = mirrors.len();
-                    pr.set_message(format!("mirror {disp_i}/{disp_len} {filename}"));
+        if settings.zig.use_community_mirrors
+            && let Some(mirrors) = community_mirrors
+        {
+            for i in 0..mirrors.len() {
+                let disp_i = i + 1;
+                let disp_len = mirrors.len();
+                pr.set_message(format!("mirror {disp_i}/{disp_len} {filename}"));
 
-                    let mirror_url = &mirrors[i];
-                    used_url = format!("{mirror_url}/{filename}");
+                let mirror_url = &mirrors[i];
+                used_url = format!("{mirror_url}/{filename}");
 
-                    if HTTP
-                        .download_file(
-                            format!("{used_url}{REQUEST_SUFFIX}"),
-                            &tarball_path,
-                            Some(pr),
-                        )
-                        .await
-                        .is_ok()
-                    {
-                        downloaded = true;
-                        break;
-                    }
+                if HTTP
+                    .download_file(
+                        format!("{used_url}{REQUEST_SUFFIX}"),
+                        &tarball_path,
+                        Some(pr),
+                    )
+                    .await
+                    .is_ok()
+                {
+                    downloaded = true;
+                    break;
                 }
             }
         }
